@@ -1,46 +1,15 @@
 #
 # NetPacket::ICMP -Decode and encode ICMP (Internet Control Message
 # Protocol) packets.
-#
-# Comments/suggestions to tpot@samba.org
-#
-# Encode and checksum by Stephanie Wehner <atrak@itsx.com>
-#
-# $Id: ICMP.pm,v 1.11 2001/07/29 23:45:00 tpot Exp $
-#
 
 package NetPacket::ICMP;
 
-#
-# Copyright (c) 2001 Tim Potter.
-#
-# This package is free software and is provided "as is" without express 
-# or implied warranty.  It may be used, redistributed and/or modified 
-# under the terms of the Perl Artistic License (see
-# http://www.perl.com/perl/misc/Artistic.html)
-#
-# Copyright (c) 1995,1996,1997,1998,1999 ANU and CSIRO on behalf of 
-# the participants in the CRC for Advanced Computational Systems
-# ('ACSys').
-#
-# ACSys makes this software and all associated data and documentation
-# ('Software') available free of charge.  You may make copies of the 
-# Software but you must include all of this notice on any copy.
-#
-# The Software was developed for research purposes and ACSys does not
-# warrant that it is error free or fit for any purpose.  ACSys
-# disclaims any liability for all claims, expenses, losses, damages
-# and costs any user may incur as a result of using, copying or
-# modifying the Software.
-#
-# Copyright (c) 2001 Stephanie Wehner
-#
 
 use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
 
-our $VERSION = '0.41_0';
+our $VERSION = '0.42.0';
 
 BEGIN {
     @ISA = qw(Exporter NetPacket);
@@ -58,7 +27,7 @@ BEGIN {
                     ICMP_REDIRECT ICMP_ECHO ICMP_ROUTERADVERT
                     ICMP_ROUTERSOLICIT ICMP_TIMXCEED ICMP_PARAMPROB
                     ICMP_TSTAMP ICMP_TSTAMPREPLY ICMP_IREQ ICMP_IREQREPLY
-                    ICMP_MASREQ ICMP_MASKREPLY
+                    ICMP_MASKREQ ICMP_MASKREPLY
     );
 
 # Tags:
@@ -69,7 +38,7 @@ BEGIN {
                        ICMP_REDIRECT ICMP_ECHO ICMP_ROUTERADVERT 
                        ICMP_ROUTERSOLICIT ICMP_TIMXCEED ICMP_PARAMPROB
                        ICMP_TSTAMP ICMP_TSTAMPREPLY ICMP_IREQ ICMP_IREQREPLY
-                       ICMP_MASREQ ICMP_MASKREPLY)],
+                       ICMP_MASKREQ ICMP_MASKREPLY)],
     strip       => [qw(icmp_strip)],
 );
 
@@ -132,7 +101,7 @@ sub strip {
     my ($pkt, @rest) = @_;
 
     my $icmp_obj = decode($pkt);
-    return $icmp_obj->data;
+    return $icmp_obj->{data};
 }
 
 #
@@ -267,7 +236,7 @@ Icmp message types:
     ICMP_REDIRECT ICMP_ECHO ICMP_ROUTERADVERT
     ICMP_ROUTERSOLICIT ICMP_TIMXCEED ICMP_PARAMPROB
     ICMP_TSTAMP ICMP_TSTAMPREPLY ICMP_IREQ ICMP_IREQREPLY
-    ICMP_MASREQ ICMP_MASKREPLY
+    ICMP_MASKREQ ICMP_MASKREPLY
 
 
 =item tags
@@ -302,26 +271,15 @@ All the above exportable items.
 
 =head1 COPYRIGHT
 
-  Copyright (c) 2001 Tim Potter.
+This is free software; you can redistribute it and/or modify it 
+under the same terms as the Perl 5 programming language system itself.
 
-  This package is free software and is provided "as is" without express 
-  or implied warranty.  It may be used, redistributed and/or modified 
-  under the terms of the Perl Artistic License (see
-  http://www.perl.com/perl/misc/Artistic.html)
+Copyright (c) 2001 Tim Potter and Stephanie Wehner.
 
-  Copyright (c) 1995,1996,1997,1998,1999 ANU and CSIRO on behalf of 
-  the participants in the CRC for Advanced Computational Systems
-  ('ACSys').
+Copyright (c) 1995,1996,1997,1998,1999 ANU and CSIRO on behalf of 
+the participants in the CRC for Advanced Computational Systems
+('ACSys').
 
-  ACSys makes this software and all associated data and documentation
-  ('Software') available free of charge.  You may make copies of the 
-  Software but you must include all of this notice on any copy.
-
-  The Software was developed for research purposes and ACSys does not
-  warrant that it is error free or fit for any purpose.  ACSys
-  disclaims any liability for all claims, expenses, losses, damages
-  and costs any user may incur as a result of using, copying or
-  modifying the Software.
 
 =head1 AUTHOR
 
