@@ -1,45 +1,15 @@
 #
 # NetPacket::UDP - Decode and encode UDP (User Datagram Protocol)
 # packets. 
-#
-# Comments/suggestions to tpot@samba.org
-# Encode and checksum by Stephanie Wehner <atrak@itsx.com>
-#
-# $Id: UDP.pm,v 1.13 2001/07/29 23:45:00 tpot Exp $
-#
 
 package NetPacket::UDP;
 
-#
-# Copyright (c) 2001 Tim Potter.
-#
-# This package is free software and is provided "as is" without express 
-# or implied warranty.  It may be used, redistributed and/or modified 
-# under the terms of the Perl Artistic License (see
-# http://www.perl.com/perl/misc/Artistic.html)
-#
-# Copyright (c) 1995,1996,1997,1998,1999 ANU and CSIRO on behalf of 
-# the participants in the CRC for Advanced Computational Systems
-# ('ACSys').
-#
-# ACSys makes this software and all associated data and documentation
-# ('Software') available free of charge.  You may make copies of the 
-# Software but you must include all of this notice on any copy.
-#
-# The Software was developed for research purposes and ACSys does not
-# warrant that it is error free or fit for any purpose.  ACSys
-# disclaims any liability for all claims, expenses, losses, damages
-# and costs any user may incur as a result of using, copying or
-# modifying the Software.
-#
-# Copyright (c) 2001 Stephanie Wehner
-#
-
 use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 use NetPacket;
+use NetPacket::IP;
 
-our $VERSION = '0.41_0';
+our $VERSION = '0.42.0';
 
 BEGIN {
     @ISA = qw(Exporter NetPacket);
@@ -135,23 +105,31 @@ sub encode {
 
 sub checksum {
 
-    my $self = shift;
-    my ($ip) = @_;
-    my ($packet,$zero,$udplen);
-    my ($src_ip, $dest_ip,$proto);
+    my( $self, $ip ) = @_;
 
-    $zero = 0;
-    $proto = NetPacket::IP::IP_PROTO_UDP;
+    my $proto = NetPacket::IP::IP_PROTO_UDP;
 
     # Pack pseudo-header for udp checksum
 
-    $src_ip = gethostbyname($ip->{src_ip});
-    $dest_ip = gethostbyname($ip->{dest_ip});
+    my $src_ip = gethostbyname($ip->{src_ip});
+    my $dest_ip = gethostbyname($ip->{dest_ip});
 
-    $packet = pack('a4a4nnnnnna*',
-            $src_ip,$dest_ip,$proto,$self->{len},
-            $self->{src_port}, $self->{dest_port}, 
-            $self->{len},$zero,$self->{data});
+    no warnings;
+
+    my $packet = pack 'a4a4CCnnnnna*' =>
+    			# fake ip header part
+            $src_ip,     
+	    $dest_ip,
+	    0,
+	    $proto,
+	    		# proper UDP part
+            $self->{src_port}, 
+	    $self->{dest_port}, 
+            $self->{len},
+	    0,
+	    $self->{data};
+
+    $packet .= "\x00" if length($packet) % 2;
 
     $self->{cksum} = NetPacket::htons(NetPacket::in_cksum($packet)); 
 
@@ -359,26 +337,14 @@ sub alterPacket
 
 =head1 COPYRIGHT
 
-  Copyright (c) 2001 Tim Potter.
+This is free software; you can redistribute it and/or modify it 
+under the same terms as the Perl 5 programming language system itself.
 
-  This package is free software and is provided "as is" without express 
-  or implied warranty.  It may be used, redistributed and/or modified 
-  under the terms of the Perl Artistic License (see
-  http://www.perl.com/perl/misc/Artistic.html)
+Copyright (c) 2001 Tim Potter.
 
-  Copyright (c) 1995,1996,1997,1998,1999 ANU and CSIRO on behalf of 
-  the participants in the CRC for Advanced Computational Systems
-  ('ACSys').
-
-  ACSys makes this software and all associated data and documentation
-  ('Software') available free of charge.  You may make copies of the 
-  Software but you must include all of this notice on any copy.
-
-  The Software was developed for research purposes and ACSys does not
-  warrant that it is error free or fit for any purpose.  ACSys
-  disclaims any liability for all claims, expenses, losses, damages
-  and costs any user may incur as a result of using, copying or
-  modifying the Software.
+Copyright (c) 1995,1996,1997,1998,1999 ANU and CSIRO on behalf of 
+the participants in the CRC for Advanced Computational Systems
+('ACSys').
 
 =head1 AUTHOR
 
@@ -386,6 +352,6 @@ Tim Potter E<lt>tpot@samba.orgE<gt>
 
 Stephanie Wehner E<lt>atrak@itsx.comE<gt>
 
-=cut
+Yanick Champoux <yanick@cpan.org>
 
-# any real autoloaded methods go after this line
+=cut
